@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Test::CheckBreaks; # git description: v0.013-6-gf2586ff
+package Dist::Zilla::Plugin::Test::CheckBreaks; # git description: v0.014-5-g97b4a00
 # ABSTRACT: Generate a test that shows what modules you are breaking
 # KEYWORDS: distribution prerequisites upstream dependencies modules conflicts breaks breakages metadata
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 
 use Moose;
 with (
@@ -212,7 +212,7 @@ __PACKAGE__->meta->make_immutable;
 #pod instead, the dependencies will be added as C<test suggests>, and the generated
 #pod test will gracefully skip checks if these modules are not available.
 #pod
-#pod Available since version 0.014.
+#pod Available since version 0.015.
 #pod
 #pod =for Pod::Coverage filename gather_files munge_files register_prereqs
 #pod
@@ -256,7 +256,7 @@ Dist::Zilla::Plugin::Test::CheckBreaks - Generate a test that shows what modules
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -310,7 +310,7 @@ prerequisite on L<CPAN::Meta::Requirements> and L<CPAN::Meta::Check> --
 instead, the dependencies will be added as C<test suggests>, and the generated
 test will gracefully skip checks if these modules are not available.
 
-Available since version 0.014.
+Available since version 0.015.
 
 =for Pod::Coverage filename gather_files munge_files register_prereqs
 
@@ -430,8 +430,8 @@ CHECK_CONFLICTS
 
         . "\n" . join("\n", $no_forced_deps
             ?
-                (map { "skip 'This information-only test requires $_', 0\n    if not eval 'require $_';" }
-                    'CPAN::Meta::Requirements', 'CPAN::Meta::Check')
+                ("skip 'This information-only test requires CPAN::Meta::Requirements', 0\n    if not eval 'require CPAN::Meta::Requirements';",
+                 "skip 'This information-only test requires CPAN::Meta::Check $cmc_prereq', 0\n    if not eval 'require CPAN::Meta::Check; CPAN::Meta::Check->VERSION($cmc_prereq)';")
             :
                 ('use CPAN::Meta::Requirements;', "use CPAN::Meta::Check $cmc_prereq;"))
         . "\n\n"
